@@ -10,9 +10,10 @@ from ._astropy_init import *
 # ----------------------------------------------------------------------------
 
 if not _ASTROPY_SETUP_:
-    from .aperture_core import *
-    from .aperture_funcs import *
+    from .aperture import *
     from .background import *
+    from .centroids import *
     from .detection import *
-    from .segmentation import *
+    from .morphology import *
     from .psf import *
+    from .segmentation import *
