@@ -8,14 +8,15 @@ from astropy.tests.pytest_plugins import *
 # exceptions
 enable_deprecations_as_exceptions()
 
-# Uncomment and customize the following lines to add/remove entries
-# from the list of packages for which version numbers are displayed
-# when running the tests
+# Uncomment and customize the following lines to add/remove entries from
+# the list of packages for which version numbers are displayed when running
+# the tests. Making it pass for KeyError is essential in some cases when
+# the package uses other astropy affiliated packages.
 try:
     PYTEST_HEADER_MODULES['Astropy'] = 'astropy'
     PYTEST_HEADER_MODULES['scikit-image'] = 'skimage'
     del PYTEST_HEADER_MODULES['h5py']
-except NameError:  # needed to support Astropy < 1.0
+except (NameError, KeyError):  # NameError is needed to support Astropy < 1.0
     pass
 
 # Uncomment the following lines to display the version number of the
@@ -25,10 +26,13 @@ import os
 
 # This is to figure out the affiliated package version, rather than
 # using Astropy's
-from . import version
+try:
+    from .version import version
+except ImportError:
+    version = 'dev'
 
 try:
     packagename = os.path.basename(os.path.dirname(__file__))
-    TESTED_VERSIONS[packagename] = version.version
+    TESTED_VERSIONS[packagename] = version
 except NameError:   # Needed to support Astropy <= 1.0.0
     pass
