@@ -7,6 +7,6 @@ from .circular_overlap import *
 from .elliptical_overlap import *
 from .rectangular_overlap import *
 
-__all__ = ['circular_overlap_grid',
-           'elliptical_overlap_grid',
+
+__all__ = ['circular_overlap_grid', 'elliptical_overlap_grid',
            'rectangular_overlap_grid']
