@@ -2,7 +2,11 @@
 """
 General-purpose utility functions.
 """
+
 from .check_random_state import *
 from .colormaps import *
+from .convolution import *
+from .cutouts import *
+from .errors import *
 from .interpolation import *
-from .prepare_data import *
+from .stats import *
